NAME

Net::DAVTalk - Interface to talk to DAV servers

SYNOPSIS

Net::DAVTalk::XMLParser is a simple wrapper around XML::Fast, returning a more usable structure like that created by XML::Simple, but running approximately 10 times faster in testing.

SUBROUTINES/METHODS

$hashref = xmlToHash($xmlstring);

Converts an XML string to a hashref of the content.

ACKNOWLEDGEMENTS

LICENSE AND COPYRIGHT

Copyright 2015-2026 Fastmail Pty Ltd.

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself; that is, either the GNU General Public License as published by the Free Software Foundation (version 1, or at your option any later version), or the Artistic License.

See http://dev.perl.org/licenses/ and the LICENSE file included with this distribution for more information.